﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.ComponentModel;
using System.Collections.ObjectModel;

namespace RadTreeListView_WPF
{
	/// <summary>
	/// A football club.
	/// </summary>
	public class Club : INotifyPropertyChanged
	{
		public event PropertyChangedEventHandler PropertyChanged;

		private string name;
		private DateTime established;
		private int stadiumCapacity;
		private ObservableCollection<Player> players;

		public string Name
		{
			get { return this.name; }
			set
			{
				if (value != this.name)
				{
					this.name = value;
					this.OnPropertyChanged("Name");
				}
			}
		}

		public DateTime Established
		{
			get { return this.established; }
			set
			{
				if (value != this.established)
				{
					this.established = value;
					this.OnPropertyChanged("Established");
				}
			}
		}

		public int StadiumCapacity
		{
			get { return this.stadiumCapacity; }
			set
			{
				if (value != this.stadiumCapacity)
				{
					this.stadiumCapacity = value;
					this.OnPropertyChanged("StadiumCapacity");
				}
			}
		}

		private int descriptionID;
		public int DescriptionID
		{
			get { return this.descriptionID; }
			set
			{
				if (value != this.descriptionID)
				{
					this.descriptionID = value;
					this.OnPropertyChanged("DescriptionID");
				}
			}
		}
		public ObservableCollection<Player> Players
		{
			get
			{
				if (null == this.players)
				{
					this.players = new ObservableCollection<Player>();
				}

				return this.players;
			}
		}

		public Club()
		{

		}

		public Club(string name, DateTime established, int stadiumCapacity, int descriptionID)
		{
			this.name = name;
			this.established = established;
			this.stadiumCapacity = stadiumCapacity;
			this.descriptionID = descriptionID;
		}

		public Club(string name, DateTime established, int stadiumCapacity, int descriptionID, ObservableCollection<Player> players)
			: this(name, established, stadiumCapacity, descriptionID)
		{
			this.players = players;
		}

		protected virtual void OnPropertyChanged(PropertyChangedEventArgs args)
		{
			PropertyChangedEventHandler handler = this.PropertyChanged;
			if (handler != null)
			{
				handler(this, args);
			}
		}

		private void OnPropertyChanged(string propertyName)
		{
			this.OnPropertyChanged(new PropertyChangedEventArgs(propertyName));
		}

		public override string ToString()
		{
			return this.Name;
		}

		public static ObservableCollection<Club> GetClubs2()
		{
			ObservableCollection<Club> clubs = new ObservableCollection<Club>();
			Club club;

			// Liverpool
			club = new Club("Liverpool", new DateTime(1892, 1, 1), 45362, 1);
			club.Players.Add(new Player("Pepe Reina", 25,  "Spain",1));
			club.Players.Add(new Player("Jamie Carragher", 23, "England",2));
			club.Players.Add(new Player("Steven Gerrard", 8, "England",3));
			club.Players.Add(new Player("Fernando Torres", 9, "Spain",4));
			clubs.Add(club);

			// Manchester Utd.
			club = new Club("Manchester Utd.", new DateTime(1878, 1, 1), 76212,2);
			club.Players.Add(new Player("Edwin van der Sar", 1, "Netherlands",5));
			club.Players.Add(new Player("Rio Ferdinand", 5,  "England",1));
			club.Players.Add(new Player("Ryan Giggs", 11,  "Wales",2));
			club.Players.Add(new Player("Wayne Rooney", 10, "England",3));
			clubs.Add(club);

		
			return clubs;
		}
		public static ObservableCollection<Club> GetClubs()
		{
			ObservableCollection<Club> clubs = new ObservableCollection<Club>();
			Club club;

			// Liverpool
			club = new Club("Liverpool", new DateTime(1892, 1, 1), 45362, 1);
			club.Players.Add(new Player("Pepe Reina", 25,  "Spain",1));
			club.Players.Add(new Player("Jamie Carragher", 23,  "England",2));
			club.Players.Add(new Player("Steven Gerrard", 8,  "England",3));
			club.Players.Add(new Player("Fernando Torres", 9, "Spain",4));
			clubs.Add(club);

			// Manchester Utd.
			club = new Club("Manchester Utd.", new DateTime(1878, 1, 1), 76212,2);
			club.Players.Add(new Player("Edwin van der Sar", 1,  "Netherlands",5));
			club.Players.Add(new Player("Rio Ferdinand", 5,  "England",1));
			club.Players.Add(new Player("Ryan Giggs", 11,  "Wales",2));
			club.Players.Add(new Player("Wayne Rooney", 10,  "England",3));
			clubs.Add(club);

			// Chelsea
			club = new Club("Chelsea", new DateTime(1905, 1, 1), 42055,3);
			club.Players.Add(new Player("Petr Čech", 1, "Czech Republic",4));
			club.Players.Add(new Player("John Terry", 26,  "England",5));
			club.Players.Add(new Player("Frank Lampard", 8,  "England",1));
			club.Players.Add(new Player("Nicolas Anelka", 39,  "France",2));
			clubs.Add(club);

			// Arsenal
			club = new Club("Arsenal", new DateTime(1886, 1, 1), 60355, 4);
			club.Players.Add(new Player("Manuel Almunia", 1,  "Spain",5));
			club.Players.Add(new Player("Gaël Clichy", 22,  "France",3));
			club.Players.Add(new Player("Cesc Fàbregas", 4, "Spain",1));
			club.Players.Add(new Player("Robin van Persie", 11,  "Netherlands",2));
			clubs.Add(club);

			return clubs;
		}
	}
}
